summaryrefslogtreecommitdiffstats
path: root/konsole
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-15 15:46:05 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-15 15:46:05 -0600
commit73c08b592db45af554b9f21029bc549d70f683ab (patch)
tree122898ea951e59fdc4419b3c84b7a6c2dd0bb5f7 /konsole
parente81bdee8ae92d6eeb82daa8c0a0e46bf37f4a6da (diff)
downloadtdebase-73c08b592db45af554b9f21029bc549d70f683ab.tar.gz
tdebase-73c08b592db45af554b9f21029bc549d70f683ab.zip
Rename a number of old tq methods that are no longer tq specific
Diffstat (limited to 'konsole')
-rw-r--r--konsole/doc/VT100/Table.Codes2
-rw-r--r--konsole/doc/VT100/techref.html2
-rw-r--r--konsole/konsole/TEScreen.cpp4
-rw-r--r--konsole/konsole/TEWidget.cpp64
-rw-r--r--konsole/konsole/TEWidget.h2
-rw-r--r--konsole/konsole/TEmuVt102.cpp2
-rw-r--r--konsole/konsole/TEmulation.cpp12
-rw-r--r--konsole/konsole/TEmulation.h2
-rw-r--r--konsole/konsole/fontembedder.cpp2
-rw-r--r--konsole/konsole/keytrans.cpp2
-rw-r--r--konsole/konsole/konsole.cpp64
-rw-r--r--konsole/konsole/konsole_part.cpp22
-rw-r--r--konsole/konsole/konsole_wcwidth.cpp2
-rw-r--r--konsole/konsole/kwrited.h4
-rw-r--r--konsole/konsole/main.cpp4
-rw-r--r--konsole/konsole/printsettings.cpp2
-rw-r--r--konsole/konsole/schema.cpp20
-rw-r--r--konsole/konsole/schema.h6
-rw-r--r--konsole/konsole/session.cpp10
-rw-r--r--konsole/konsole/zmodem_dialog.cpp2
20 files changed, 115 insertions, 115 deletions
diff --git a/konsole/doc/VT100/Table.Codes b/konsole/doc/VT100/Table.Codes
index 2f0554a0b..6ece0f4bf 100644
--- a/konsole/doc/VT100/Table.Codes
+++ b/konsole/doc/VT100/Table.Codes
@@ -1070,7 +1070,7 @@ DECALN.sect Command
DECALN.code HSH|8|
DECALN.text
Causes the VT100 to fill it's screen with
- uppercase Es for screen focus and tqalignment.
+ uppercase Es for screen focus and alignment.
DECALN.table.XPS
Subcode|Emulation|Scope|Operation|Args|Meaning
N/A|VT100|scr|helpAlign||see above
diff --git a/konsole/doc/VT100/techref.html b/konsole/doc/VT100/techref.html
index 6b39bda55..6e36f39e5 100644
--- a/konsole/doc/VT100/techref.html
+++ b/konsole/doc/VT100/techref.html
@@ -2234,7 +2234,7 @@ Work is currently in progress to fix this issue.
<tr><td><p></td>
<tr><td></td>
<td colspan=6> Causes the VT100 to fill it's screen with
- uppercase Es for screen focus and tqalignment.
+ uppercase Es for screen focus and alignment.
<tr><td><p></td></tr>
<tr>
<td></td>
diff --git a/konsole/konsole/TEScreen.cpp b/konsole/konsole/TEScreen.cpp
index 7af02c247..2c6f9f42d 100644
--- a/konsole/konsole/TEScreen.cpp
+++ b/konsole/konsole/TEScreen.cpp
@@ -783,7 +783,7 @@ void TEScreen::compose(TQString compose)
TQChar c(image[lastPos].c);
compose.prepend(c);
compose.compose();
- image[lastPos].c = compose[0].tqunicode();
+ image[lastPos].c = compose[0].unicode();
}
// Region commands -------------------------------------------------------------
@@ -1023,7 +1023,7 @@ void TEScreen::clearEntireScreen()
}
/*! fill screen with 'E'
- This is to aid screen tqalignment
+ This is to aid screen alignment
*/
void TEScreen::helpAlign()
diff --git a/konsole/konsole/TEWidget.cpp b/konsole/konsole/TEWidget.cpp
index 38862fb18..7c49f8c79 100644
--- a/konsole/konsole/TEWidget.cpp
+++ b/konsole/konsole/TEWidget.cpp
@@ -57,11 +57,11 @@
#include <tqapplication.h>
#include <tqpainter.h>
-#include <tqclipboard.h>
+#include <clipboard.h>
#include <tqstyle.h>
#include <tqfile.h>
#include <tqdragobject.h>
-#include <tqlayout.h>
+#include <layout.h>
#include <tqregexp.h>
#include <math.h>
@@ -193,10 +193,10 @@ void TEWidget::setColorTable(const ColorEntry table[])
xterm fonts have these at 0x00..0x1f.
QT's iso mapping leaves 0x00..0x7f without any changes. But the graphicals
- come in here as proper tqunicode characters.
+ come in here as proper unicode characters.
We treat non-iso10646 fonts as VT100 extended and do the requiered mapping
- from tqunicode to 0x00..0x1f. The remaining translation is then left to the
+ from unicode to 0x00..0x1f. The remaining translation is then left to the
QCodec.
*/
@@ -215,7 +215,7 @@ unsigned short vt100_graphics[32] =
/*
static TQChar vt100extended(TQChar c)
{
- switch (c.tqunicode())
+ switch (c.unicode())
{
case 0x25c6 : return 1;
case 0x2592 : return 2;
@@ -391,7 +391,7 @@ TEWidget::TEWidget(TQWidget *parent, const char *name)
// konsole in opaque mode.
bY = bX = 1;
- cb = TQApplication::tqclipboard();
+ cb = TQApplication::clipboard();
TQObject::connect( (TQObject*)cb, TQT_SIGNAL(selectionChanged()),
this, TQT_SLOT(onClearSelection()) );
@@ -441,7 +441,7 @@ TEWidget::~TEWidget()
/* ------------------------------------------------------------------------- */
/**
- A table for emulating the simple (single width) tqunicode drawing chars.
+ A table for emulating the simple (single width) unicode drawing chars.
It represents the 250x - 257x glyphs. If it's zero, we can't use it.
if it's not, it's encoded as follows: imagine a 5x5 grid where the points are numbered
0 to 24 left to top, top to bottom. Each point is represented by the corresponding bit.
@@ -564,7 +564,7 @@ void TEWidget::drawTextFixed(TQPainter &paint, int x, int y,
int w;
for(unsigned int i=0;i<str.length();i++)
{
- drawstr = str.tqat(i);
+ drawstr = str.at(i);
// Add double of the width if next c is 0;
if ((attr+nc+1)->c) // This may access image[image_size] See makeImage()
{
@@ -578,7 +578,7 @@ void TEWidget::drawTextFixed(TQPainter &paint, int x, int y,
}
//Check for line-drawing char
- if (isLineChar(drawstr[0].tqunicode()))
+ if (isLineChar(drawstr[0].unicode()))
{
uchar code = drawstr[0].cell();
if (LineChars[code])
@@ -814,7 +814,7 @@ void TEWidget::setImage(const ca* const newimg, int lines, int columns)
int y,x,len;
const TQPixmap* pm = backgroundPixmap();
TQPainter paint;
- tqsetUpdatesEnabled(false);
+ setUpdatesEnabled(false);
paint.begin( this );
TQPoint tL = contentsRect().topLeft();
@@ -926,7 +926,7 @@ void TEWidget::setImage(const ca* const newimg, int lines, int columns)
}
drawFrame( &paint );
paint.end();
- tqsetUpdatesEnabled(true);
+ setUpdatesEnabled(true);
if ( hasBlinker && !blinkT->isActive()) blinkT->start(1000); // 1000 ms
if (!hasBlinker && blinkT->isActive()) { blinkT->stop(); blinking = false; }
free(dirtyMask);
@@ -954,7 +954,7 @@ void TEWidget::setImage(const ca* const newimg, int lines, int columns)
mResizeLabel = new TQLabel(i18n("Size: XXX x XXX"), mResizeWidget);
l->addWidget(mResizeLabel, 1, AlignCenter);
mResizeWidget->setMinimumWidth(mResizeLabel->fontMetrics().width(i18n("Size: XXX x XXX"))+20);
- mResizeWidget->setMinimumHeight(mResizeLabel->tqsizeHint().height()+20);
+ mResizeWidget->setMinimumHeight(mResizeLabel->sizeHint().height()+20);
mResizeTimer = new TQTimer(this);
connect(mResizeTimer, TQT_SIGNAL(timeout()), mResizeWidget, TQT_SLOT(hide()));
}
@@ -993,7 +993,7 @@ void TEWidget::paintEvent( TQPaintEvent* pe )
{
const TQPixmap* pm = backgroundPixmap();
TQPainter paint;
- tqsetUpdatesEnabled(false);
+ setUpdatesEnabled(false);
paint.begin( this );
paint.setBackgroundMode( Qt::TransparentMode );
@@ -1051,7 +1051,7 @@ void TEWidget::paintEvent( TQPaintEvent* pe )
erase( er );
paint.end();
- tqsetUpdatesEnabled(true);
+ setUpdatesEnabled(true);
}
void TEWidget::print(TQPainter &paint, bool friendly, bool exact)
@@ -1072,7 +1072,7 @@ void TEWidget::print(TQPainter &paint, bool friendly, bool exact)
pm.fill();
TQPainter pm_paint;
- pm_paint.tqbegin(&pm, TQT_TQWIDGET(this));
+ pm_paint.begin(&pm, TQT_TQWIDGET(this));
paintContents(pm_paint, contentsRect(), true);
pm_paint.end();
paint.drawPixmap(0, 0, pm);
@@ -1159,14 +1159,14 @@ void TEWidget::blinkEvent()
{
blinking = !blinking;
isBlinkEvent = true;
- tqrepaint(false);
+ repaint(false);
isBlinkEvent = false;
}
void TEWidget::blinkCursorEvent()
{
cursorBlinking = !cursorBlinking;
- tqrepaint(cursorRect, true);
+ repaint(cursorRect, true);
}
/* ------------------------------------------------------------------------- */
@@ -1185,9 +1185,9 @@ void TEWidget::propagateSize()
if (isFixedSize)
{
setSize(columns, lines);
- TQFrame::setFixedSize(tqsizeHint());
+ TQFrame::setFixedSize(sizeHint());
parentWidget()->adjustSize();
- parentWidget()->setFixedSize(parentWidget()->tqsizeHint());
+ parentWidget()->setFixedSize(parentWidget()->sizeHint());
return;
}
if (image)
@@ -1742,14 +1742,14 @@ void TEWidget::mouseTripleClickEvent(TQMouseEvent* ev)
void TEWidget::focusInEvent( TQFocusEvent * )
{
- tqrepaint(cursorRect, true); // *do* erase area, to get rid of the
+ repaint(cursorRect, true); // *do* erase area, to get rid of the
// hollow cursor rectangle.
}
void TEWidget::focusOutEvent( TQFocusEvent * )
{
- tqrepaint(cursorRect, true); // don't erase area
+ repaint(cursorRect, true); // don't erase area
}
bool TEWidget::focusNextPrevChild( bool next )
@@ -1803,8 +1803,8 @@ void TEWidget::emitText(TQString text)
void TEWidget::emitSelection(bool useXselection,bool appendReturn)
// Paste Clipboard by simulating keypress events
{
- TQApplication::tqclipboard()->setSelectionMode( useXselection );
- TQString text = TQApplication::tqclipboard()->text();
+ TQApplication::clipboard()->setSelectionMode( useXselection );
+ TQString text = TQApplication::clipboard()->text();
if(appendReturn)
text.append("\r");
if ( ! text.isEmpty() )
@@ -1814,13 +1814,13 @@ void TEWidget::emitSelection(bool useXselection,bool appendReturn)
emit keyPressedSignal(&e); // expose as a big fat keypress event
emit clearSelectionSignal();
}
- TQApplication::tqclipboard()->setSelectionMode( false );
+ TQApplication::clipboard()->setSelectionMode( false );
}
void TEWidget::setSelection(const TQString& t)
{
// Disconnect signal while WE set the clipboard
- TQClipboard *cb = TQApplication::tqclipboard();
+ TQClipboard *cb = TQApplication::clipboard();
TQObject::disconnect( cb, TQT_SIGNAL(selectionChanged()),
this, TQT_SLOT(onClearSelection()) );
@@ -1860,7 +1860,7 @@ void TEWidget::onClearSelection()
//FIXME: an `eventFilter' has been installed instead of a `keyPressEvent'
// due to a bug in `QT' or the ignorance of the author to prevent
-// tqrepaint events being emitted to the screen whenever one leaves
+// repaint events being emitted to the screen whenever one leaves
// or reenters the screen to/from another application.
//
// Troll says one needs to change focusInEvent() and focusOutEvent(),
@@ -1880,7 +1880,7 @@ void TEWidget::doScroll(int lines)
bool TEWidget::eventFilter( TQObject *obj, TQEvent *e )
{
if ( (e->type() == TQEvent::Accel ||
- e->type() == TQEvent::AccelAvailable ) && tqApp->tqfocusWidget() == this )
+ e->type() == TQEvent::AccelAvailable ) && tqApp->focusWidget() == this )
{
TQT_TQKEYEVENT( e )->ignore();
return false;
@@ -1984,7 +1984,7 @@ void TEWidget::imEndEvent( TQIMEvent *e )
m_imPreeditLength = 0;
m_isIMEdit = m_isIMSel = false;
- tqrepaint( repaintRect, true );
+ repaint( repaintRect, true );
}
// Override any Ctrl+<key> accelerator when pressed with the keyboard
@@ -2104,7 +2104,7 @@ void TEWidget::clearImage()
void TEWidget::calcGeometry()
{
- scrollbar->resize(TQApplication::tqstyle().tqpixelMetric(TQStyle::PM_ScrollBarExtent),
+ scrollbar->resize(TQApplication::tqstyle().pixelMetric(TQStyle::PM_ScrollBarExtent),
contentsRect().height());
switch(scrollLoc)
{
@@ -2177,7 +2177,7 @@ void TEWidget::setFixedSize(int cols, int lins)
TQFrame::setFixedSize(m_size);
}
-TQSize TEWidget::tqsizeHint() const
+TQSize TEWidget::sizeHint() const
{
return m_size;
}
@@ -2242,7 +2242,7 @@ void TEWidget::dropEvent(TQDropEvent* event)
TQString tmp;
if (url.isLocalFile()) {
tmp = url.path(); // local URL : remove protocol. This helps "ln" & "cd" and doesn't harm the others
- } else if ( url.protocol() == TQString::tqfromLatin1( "mailto" ) ) {
+ } else if ( url.protocol() == TQString::fromLatin1( "mailto" ) ) {
justPaste = true;
break;
} else {
@@ -2268,7 +2268,7 @@ void TEWidget::dropEvent(TQDropEvent* event)
void TEWidget::doDrag()
{
dragInfo.state = diDragging;
- dragInfo.dragObject = new TQTextDrag(TQApplication::tqclipboard()->text(TQClipboard::Selection), this);
+ dragInfo.dragObject = new TQTextDrag(TQApplication::clipboard()->text(TQClipboard::Selection), this);
dragInfo.dragObject->dragCopy();
// Don't delete the TQTextDrag object. Qt will delete it when it's done with it.
}
diff --git a/konsole/konsole/TEWidget.h b/konsole/konsole/TEWidget.h
index afb1ff3a8..197ec860c 100644
--- a/konsole/konsole/TEWidget.h
+++ b/konsole/konsole/TEWidget.h
@@ -98,7 +98,7 @@ public:
void updateImageSize();
void setSize(int cols, int lins);
void setFixedSize(int cols, int lins);
- TQSize tqsizeHint() const;
+ TQSize sizeHint() const;
void setWordCharacters(TQString wc);
TQString wordCharacters() { return word_characters; }
diff --git a/konsole/konsole/TEmuVt102.cpp b/konsole/konsole/TEmuVt102.cpp
index f704297cf..e8ee73b64 100644
--- a/konsole/konsole/TEmuVt102.cpp
+++ b/konsole/konsole/TEmuVt102.cpp
@@ -307,7 +307,7 @@ void TEmuVt102::initTokenizer()
#define ESC 27
#define CNTL(c) ((c)-'@')
-// process an incoming tqunicode character
+// process an incoming unicode character
void TEmuVt102::onRcvChar(int cc)
{ int i;
diff --git a/konsole/konsole/TEmulation.h b/konsole/konsole/TEmulation.h
index a5f432175..58d1a91b1 100644
--- a/konsole/konsole/TEmulation.h
+++ b/konsole/konsole/TEmulation.h
@@ -25,7 +25,7 @@
#include "TEScreen.h"
#include <tqtimer.h>
#include <stdio.h>
-#include <tqtextcodec.h>
+#include <textcodec.h>
#include <tqguardedptr.h>
#include <keytrans.h>
diff --git a/konsole/konsole/fontembedder.cpp b/konsole/konsole/fontembedder.cpp
index d0c17e084..8e26f574b 100644
--- a/konsole/konsole/fontembedder.cpp
+++ b/konsole/konsole/fontembedder.cpp
@@ -19,7 +19,7 @@
*/
#include <tqfile.h>
-#include <tqtextstream.h>
+#include <textstream.h>
#include <stdlib.h>
#include <iostream>
#include <iomanip>
diff --git a/konsole/konsole/keytrans.cpp b/konsole/konsole/keytrans.cpp
index b3aa76e9f..18d453a58 100644
--- a/konsole/konsole/keytrans.cpp
+++ b/konsole/konsole/keytrans.cpp
@@ -362,7 +362,7 @@ void KeyTrans::readConfig()
;
TQBuffer* newbuf;
newbuf = new TQBuffer();
- newbuf->tqsetBufferFromCopy(txt);
+ newbuf->setBuffer(txt);
buf=TQT_TQIODEVICE(newbuf);
}
else
diff --git a/konsole/konsole/konsole.cpp b/konsole/konsole/konsole.cpp
index 7c9395da5..e4a11b971 100644
--- a/konsole/konsole/konsole.cpp
+++ b/konsole/konsole/konsole.cpp
@@ -85,7 +85,7 @@ Time to start a requirement list.
#include <tqspinbox.h>
#include <tqcheckbox.h>
#include <tqimage.h>
-#include <tqlayout.h>
+#include <layout.h>
#include <tqpushbutton.h>
#include <tqhbox.h>
#include <tqtoolbutton.h>
@@ -1158,7 +1158,7 @@ void Konsole::makeBasicGUI()
TQT_TQOBJECT(this), TQT_SLOT(nextSession()), m_shortcuts, "next_session");
for (int i=1;i<13;i++) { // Due to 12 function keys?
- new KAction(i18n("Switch to Session %1").tqarg(i), 0, TQT_TQOBJECT(this), TQT_SLOT(switchToSession()), m_shortcuts, TQString(TQString().sprintf("switch_to_session_%02d", i)).latin1());
+ new KAction(i18n("Switch to Session %1").arg(i), 0, TQT_TQOBJECT(this), TQT_SLOT(switchToSession()), m_shortcuts, TQString(TQString().sprintf("switch_to_session_%02d", i)).latin1());
}
new KAction(i18n("Enlarge Font"), 0, TQT_TQOBJECT(this), TQT_SLOT(biggerFont()), m_shortcuts, "bigger_font");
@@ -1289,7 +1289,7 @@ void Konsole::setColLin(int columns, int lines)
te->setSize(columns, lines);
adjustSize();
if (b_fixedSize)
- setFixedSize(tqsizeHint());
+ setFixedSize(sizeHint());
notifySize(columns, lines); // set menu items
}
}
@@ -1313,7 +1313,7 @@ void Konsole::slotTabContextMenu(TQWidget* _te, const TQPoint & pos)
if (!m_menuCreated)
makeGUI();
- m_contextMenuSession = sessions.tqat( tabwidget->indexOf( _te ) );
+ m_contextMenuSession = sessions.at( tabwidget->indexOf( _te ) );
m_tabDetachSession->setEnabled( tabwidget->count()>1 );
@@ -1384,12 +1384,12 @@ void Konsole::slotTabSetViewOptions(int mode)
for(int i = 0; i < tabwidget->count(); i++) {
TQWidget *page = tabwidget->page(i);
- TQIconSet icon = iconSetForSession(sessions.tqat(i));
+ TQIconSet icon = iconSetForSession(sessions.at(i));
TQString title;
if (b_matchTabWinTitle)
- title = sessions.tqat(i)->fullTitle();
+ title = sessions.at(i)->fullTitle();
else
- title = sessions.tqat(i)->Title();
+ title = sessions.at(i)->Title();
title=title.replace('&',"&&");
switch(mode) {
@@ -1437,7 +1437,7 @@ void Konsole::slotSaveSessionsProfile()
TQString::null, &ok, this );
if ( ok ) {
TQString path = locateLocal( "data",
- TQString::tqfromLatin1( "konsole/profiles/" ) + prof,
+ TQString::fromLatin1( "konsole/profiles/" ) + prof,
KGlobal::instance() );
if ( TQFile::exists( path ) )
@@ -1622,7 +1622,7 @@ void Konsole::readProperties(KConfig* config, const TQString &schema, bool globa
ColorSchema* sch = colors->find(schema.isEmpty() ? s_kconfigSchema : schema);
if (!sch)
{
- sch = (ColorSchema*)colors->tqat(0); //the default one
+ sch = (ColorSchema*)colors->at(0); //the default one
kdWarning() << "Could not find schema named " <<s_kconfigSchema<<"; using "<<sch->relPath()<<endl;
s_kconfigSchema = sch->relPath();
}
@@ -1650,7 +1650,7 @@ void Konsole::readProperties(KConfig* config, const TQString &schema, bool globa
delete rootxpms[te];
rootxpms.remove(te);
}
- pixmap_menu_activated(sch->tqalignment());
+ pixmap_menu_activated(sch->alignment());
}
te->setColorTable(sch->table()); //FIXME: set twice here to work around a bug
@@ -1886,7 +1886,7 @@ void Konsole::updateSchemaMenu()
m_schema->clear();
for (int i = 0; i < (int) colors->count(); i++)
{
- ColorSchema* s = (ColorSchema*)colors->tqat(i);
+ ColorSchema* s = (ColorSchema*)colors->at(i);
assert( s );
TQString title=s->title();
m_schema->insertItem(title.replace('&',"&&"),s->numb(),0);
@@ -1927,7 +1927,7 @@ void Konsole::slotToggleMenubar() {
if (b_fixedSize)
{
adjustSize();
- setFixedSize(tqsizeHint());
+ setFixedSize(sizeHint());
}
if (!showMenubar->isChecked()) {
setCaption(i18n("Use the right mouse button to bring back the menu"));
@@ -2002,12 +2002,12 @@ void Konsole::slotSelectTabbar() {
/* FIXME: Still necessary ? */
TQPtrDictIterator<KRootPixmap> it(rootxpms);
for (;it.current();++it)
- it.current()->tqrepaint(true);
+ it.current()->repaint(true);
if (b_fixedSize)
{
adjustSize();
- setFixedSize(tqsizeHint());
+ setFixedSize(sizeHint());
}
}
@@ -2129,7 +2129,7 @@ void Konsole::reparseConfiguration()
ColorSchema* sch = colors->find(s_kconfigSchema);
if (!sch)
{
- sch = (ColorSchema*)colors->tqat(0); //the default one
+ sch = (ColorSchema*)colors->at(0); //the default one
kdWarning() << "Could not find schema named " <<s_kconfigSchema<<"; using "<<sch->relPath()<<endl;
s_kconfigSchema = sch->relPath();
}
@@ -2500,7 +2500,7 @@ TQString Konsole::sessionId(const int position)
if (position<=0 || position>(int)sessions.count())
return "";
- return sessions.tqat(position-1)->SessionId();
+ return sessions.at(position-1)->SessionId();
}
void Konsole::listSessions()
@@ -2526,7 +2526,7 @@ void Konsole::activateSession(int position)
{
if (position<0 || position>=(int)sessions.count())
return;
- activateSession( sessions.tqat(position) );
+ activateSession( sessions.at(position) );
}
void Konsole::activateSession(TQWidget* w)
@@ -2586,11 +2586,11 @@ void Konsole::activateSession(TESession *s)
// Set the required schema variables for the current session
ColorSchema* cs = colors->find( se->schemaNo() );
if (!cs)
- cs = (ColorSchema*)colors->tqat(0); //the default one
+ cs = (ColorSchema*)colors->at(0); //the default one
s_schema = cs->relPath();
curr_schema = cs->numb();
pmPath = cs->imagePath();
- n_render = cs->tqalignment();
+ n_render = cs->alignment();
// BR 106464 temporary fix...
// only 2 sessions opened, 2nd session viewable, right-click on 1st tab and
@@ -2632,7 +2632,7 @@ void Konsole::activateSession(TESession *s)
if (monitorSilence) monitorSilence->setChecked( se->isMonitorSilence() );
masterMode->setChecked( se->isMasterMode() );
sessions.find(se);
- uint position=sessions.tqat();
+ uint position=sessions.at();
if (m_moveSessionLeft) m_moveSessionLeft->setEnabled(position>0);
if (m_moveSessionRight) m_moveSessionRight->setEnabled(position<sessions.count()-1);
}
@@ -2871,7 +2871,7 @@ TQString Konsole::newSession(KSimpleConfig *co, TQString program, const TQStrLis
ColorSchema* schema = colors->find(sch);
if (!schema)
- schema=(ColorSchema*)colors->tqat(0); //the default one
+ schema=(ColorSchema*)colors->at(0); //the default one
int schmno = schema->numb();
if (sessions.count()==1 && n_tabbar!=TabNone)
@@ -3063,7 +3063,7 @@ void Konsole::doneSession(TESession* s)
se = 0;
if (sessions.count())
{
- se = sessions.tqat(sessionIndex ? sessionIndex - 1 : 0);
+ se = sessions.at(sessionIndex ? sessionIndex - 1 : 0);
session2action.find(se)->setChecked(true);
//FIXME: this Timer stupidity originated from the connected
@@ -3081,7 +3081,7 @@ void Konsole::doneSession(TESession* s)
}
else {
sessions.find(se);
- uint position=sessions.tqat();
+ uint position=sessions.at();
m_moveSessionLeft->setEnabled(position>0);
m_moveSessionRight->setEnabled(position<sessions.count()-1);
}
@@ -3135,7 +3135,7 @@ void Konsole::slotMovedTab(int from, int to)
void Konsole::moveSessionLeft()
{
sessions.find(se);
- uint position=sessions.tqat();
+ uint position=sessions.at();
if (position==0)
return;
@@ -3167,7 +3167,7 @@ void Konsole::moveSessionLeft()
void Konsole::moveSessionRight()
{
sessions.find(se);
- uint position=sessions.tqat();
+ uint position=sessions.at();
if (position==sessions.count()-1)
return;
@@ -3498,7 +3498,7 @@ void Konsole::addScreenSession(const TQString &path, const TQString &socket)
co->writeEntry("Name", socket);
TQString txt = i18n("Screen is a program controlling screens!", "Screen at %1").arg(socket);
co->writeEntry("Comment", txt);
- co->writePathEntry("Exec", TQString::tqfromLatin1("SCREENDIR=%1 screen -r %2")
+ co->writePathEntry("Exec", TQString::fromLatin1("SCREENDIR=%1 screen -r %2")
.arg(path).arg(socket));
TQString icon = "konsole";
cmd_serial++;
@@ -3570,7 +3570,7 @@ void Konsole::setSchema(int numb, TEWidget* tewidget)
ColorSchema* s = colors->find(numb);
if (!s)
{
- s = (ColorSchema*)colors->tqat(0);
+ s = (ColorSchema*)colors->at(0);
kdWarning() << "No schema with serial #"<<numb<<", using "<<s->relPath()<<" (#"<<s->numb()<<")." << endl;
s_kconfigSchema = s->relPath();
}
@@ -3587,7 +3587,7 @@ void Konsole::setSchema(const TQString & path)
ColorSchema* s = colors->find(path);
if (!s)
{
- s = (ColorSchema*)colors->tqat(0); //the default one
+ s = (ColorSchema*)colors->at(0); //the default one
kdWarning() << "No schema with the name " <<path<<", using "<<s->relPath()<<endl;
s_kconfigSchema = s->relPath();
}
@@ -3639,7 +3639,7 @@ void Konsole::setSchema(ColorSchema* s, TEWidget* tewidget)
delete rootxpms[tewidget];
rootxpms.remove(tewidget);
}
- pixmap_menu_activated(s->tqalignment(), tewidget);
+ pixmap_menu_activated(s->alignment(), tewidget);
tewidget->setBlendColor(tqRgba(0, 0, 0, 0xff));
}
@@ -3718,7 +3718,7 @@ void Konsole::detachSession(TESession* _se) {
if (se_previous)
se = se_previous;
else
- se = sessions.tqat(sessionIndex ? sessionIndex - 1 : 0);
+ se = sessions.at(sessionIndex ? sessionIndex - 1 : 0);
session2action.find(se)->setChecked(true);
TQTimer::singleShot(1,this,TQT_SLOT(activateSession()));
}
@@ -3992,7 +3992,7 @@ void Konsole::slotOpenSelection()
m_filterData = new KURIFilterData( selectedURL );
KURIFilter::self()->filterURI( *(m_filterData) );
- m_openSelection->insertItem( SmallIconSet( m_filterData->iconName() ),i18n( "%1" ).tqarg(m_filterData->uri().url()), 1 );
+ m_openSelection->insertItem( SmallIconSet( m_filterData->iconName() ),i18n( "%1" ).arg(m_filterData->uri().url()), 1 );
connect(m_openSelection, TQT_SIGNAL(activated(int)), TQT_SLOT(slotOpenURI(int)));
}
@@ -4207,7 +4207,7 @@ void Konsole::toggleBidi()
TQPtrList<TEWidget> tes = activeTEs();
for (TEWidget *_te = tes.first(); _te; _te = tes.next()) {
_te->setBidiEnabled(b_bidiEnabled);
- _te->tqrepaint();
+ _te->repaint();
}
}
diff --git a/konsole/konsole/konsole_part.cpp b/konsole/konsole/konsole_part.cpp
index b5463f8fb..484c4a0fa 100644
--- a/konsole/konsole/konsole_part.cpp
+++ b/konsole/konsole/konsole_part.cpp
@@ -24,7 +24,7 @@
#include <assert.h>
#include <tqfile.h>
-#include <tqlayout.h>
+#include <layout.h>
#include <tqwmatrix.h>
#include <kaboutdata.h>
@@ -577,7 +577,7 @@ void konsolePart::readProperties()
s_kconfigSchema=config->readEntry("schema");
ColorSchema* sch = colors->find(schema.isEmpty() ? s_kconfigSchema : schema);
if (!sch) {
- sch=(ColorSchema*)colors->tqat(0); //the default one
+ sch=(ColorSchema*)colors->at(0); //the default one
}
if (sch->hasSchemaFileChanged()) sch->rereadSchemaFile();
s_schema = sch->relPath();
@@ -591,7 +591,7 @@ void konsolePart::readProperties()
rootxpm = new KRootPixmap(TQT_TQWIDGET(te));
rootxpm->setFadeEffect(sch->tr_x(), TQColor(sch->tr_r(), sch->tr_g(), sch->tr_b()));
rootxpm->start();
- rootxpm->tqrepaint(true);
+ rootxpm->repaint(true);
}
else {
te->setBlendColor(tqRgba(sch->tr_r(), sch->tr_g(), sch->tr_b(), int(sch->tr_x() * 255)));
@@ -604,7 +604,7 @@ void konsolePart::readProperties()
delete rootxpm;
rootxpm=0;
}
- pixmap_menu_activated(sch->tqalignment());
+ pixmap_menu_activated(sch->alignment());
}
te->setBellMode(n_bell);
@@ -737,7 +737,7 @@ void konsolePart::updateSchemaMenu()
m_schema->clear();
for (int i = 0; i < (int) colors->count(); i++) {
- ColorSchema* s = (ColorSchema*)colors->tqat(i);
+ ColorSchema* s = (ColorSchema*)colors->at(i);
TQString title=s->title();
m_schema->insertItem(title.replace('&',"&&"),s->numb(),0);
}
@@ -752,7 +752,7 @@ void konsolePart::setSchema(int numb)
ColorSchema* s = colors->find(numb);
if (!s) {
kdWarning() << "No schema found. Using default." << endl;
- s=(ColorSchema*)colors->tqat(0);
+ s=(ColorSchema*)colors->at(0);
}
if (s->numb() != numb) {
kdWarning() << "No schema with number " << numb << endl;
@@ -785,7 +785,7 @@ void konsolePart::setSchema(ColorSchema* s)
rootxpm = new KRootPixmap(TQT_TQWIDGET(te));
rootxpm->setFadeEffect(s->tr_x(), TQColor(s->tr_r(), s->tr_g(), s->tr_b()));
rootxpm->start();
- rootxpm->tqrepaint(true);
+ rootxpm->repaint(true);
}
else {
te->setBlendColor(tqRgba(s->tr_r(), s->tr_g(), s->tr_b(), int(s->tr_x() * 255)));
@@ -798,7 +798,7 @@ void konsolePart::setSchema(ColorSchema* s)
delete rootxpm;
rootxpm=0;
}
- pixmap_menu_activated(s->tqalignment());
+ pixmap_menu_activated(s->alignment());
}
te->setColorTable(s->table());
@@ -809,8 +809,8 @@ void konsolePart::notifySize(int /* columns */, int /* lines */)
{
ColorSchema *sch=colors->find(s_schema);
- if (sch && sch->tqalignment() >= 3)
- pixmap_menu_activated(sch->tqalignment());
+ if (sch && sch->alignment() >= 3)
+ pixmap_menu_activated(sch->alignment());
}
void konsolePart::pixmap_menu_activated(int item)
@@ -1137,7 +1137,7 @@ void konsolePart::showShellInDir( const TQString& dir )
{
TQString text = dir;
KRun::shellQuote(text);
- text = TQString::tqfromLatin1("cd ") + text + '\n';
+ text = TQString::fromLatin1("cd ") + text + '\n';
te->emitText( text );
};
}
diff --git a/konsole/konsole/konsole_wcwidth.cpp b/konsole/konsole/konsole_wcwidth.cpp
index 63abe8dd1..098cd16d4 100644
--- a/konsole/konsole/konsole_wcwidth.cpp
+++ b/konsole/konsole/konsole_wcwidth.cpp
@@ -214,7 +214,7 @@ int string_width( const TQString &txt )
int w = 0;
for ( uint i = 1; i < txt.length(); ++i ) {
- w += konsole_wcwidth(txt[i].tqunicode());
+ w += konsole_wcwidth(txt[i].unicode());
}
return w;
}
diff --git a/konsole/konsole/kwrited.h b/konsole/konsole/kwrited.h
index 7c051c51a..5c3bca468 100644
--- a/konsole/konsole/kwrited.h
+++ b/konsole/konsole/kwrited.h
@@ -21,10 +21,10 @@
#ifndef KWRITED_H
#define KWRITED_H
-#include <tqtextedit.h>
+#include <textedit.h>
#include <kdedmodule.h>
#include <tqpopupmenu.h>
-#include <tqtextedit.h>
+#include <textedit.h>
class KPty;
diff --git a/konsole/konsole/main.cpp b/konsole/konsole/main.cpp
index 1f40e8c14..cb21f6aff 100644
--- a/konsole/konsole/main.cpp
+++ b/konsole/konsole/main.cpp
@@ -271,7 +271,7 @@ extern "C" int KDE_EXPORT kdemain(int argc, char* argv[])
TQString term = "";
if(args->isSet("tn")) {
- term=TQString::tqfromLatin1(args->getOption("tn"));
+ term=TQString::fromLatin1(args->getOption("tn"));
}
login_shell = args->isSet("ls");
@@ -591,7 +591,7 @@ extern "C" int KDE_EXPORT kdemain(int argc, char* argv[])
//// Temporary code, waiting for Qt to do this properly
// Delete all toplevel widgets that have WDestructiveClose
- TQWidgetList *list = TQApplication::tqtopLevelWidgets();
+ TQWidgetList *list = TQApplication::topLevelWidgets();
// remove all toplevel widgets that have a parent (i.e. they
// got WTopLevel explicitly), they'll be deleted by the parent
list->first();
diff --git a/konsole/konsole/printsettings.cpp b/konsole/konsole/printsettings.cpp
index 8daa6c40e..3b82ee7a0 100644
--- a/konsole/konsole/printsettings.cpp
+++ b/konsole/konsole/printsettings.cpp
@@ -22,7 +22,7 @@
#include <klocale.h>
#include <tqcheckbox.h>
-#include <tqlayout.h>
+#include <layout.h>
PrintSettings::PrintSettings(TQWidget *parent, const char *name)
: KPrintDialogPage(parent, name)
diff --git a/konsole/konsole/schema.cpp b/konsole/konsole/schema.cpp
index b3bae8eff..8d85329eb 100644
--- a/konsole/konsole/schema.cpp
+++ b/konsole/konsole/schema.cpp
@@ -131,7 +131,7 @@ ColorSchema::ColorSchema(const TQString& pathname)
,lastRead(new TQDateTime())
{
//start with a valid time, aleXXX
- *lastRead = TQDateTime::tqcurrentDateTime();
+ *lastRead = TQDateTime::currentDateTime();
TQString fPath = pathname.startsWith("/") ? pathname : locate("data", "konsole/"+pathname);
if (fPath.isEmpty() || !TQFile::exists(fPath))
{
@@ -169,7 +169,7 @@ ColorSchema::ColorSchema(KConfig& c)
m_title = c.readEntry("Title",i18n("[no title]"));
m_imagePath = c.readEntry("ImagePath");
- m_tqalignment = c.readNumEntry("ImageAlignment",1);
+ m_alignment = c.readNumEntry("ImageAlignment",1);
m_useTransparency = c.readBoolEntry("UseTransparency",false);
m_tr_r = c.readNumEntry("TransparentR",0);
@@ -203,7 +203,7 @@ void ColorSchema::clearSchema()
}
m_title = i18n("[no title]");
m_imagePath = "";
- m_tqalignment = 1;
+ m_alignment = 1;
m_useTransparency = false;
m_tr_x = 0.0;
m_tr_r = 0;
@@ -216,7 +216,7 @@ void ColorSchema::setDefaultSchema()
m_numb = 0;
m_title = i18n("Konsole Default");
m_imagePath = ""; // background pixmap
- m_tqalignment = 1; // none
+ m_alignment = 1; // none
m_useTransparency = false; // not use pseudo-transparency by default
m_tr_r = m_tr_g = m_tr_b = 0; // just to be on the safe side
m_tr_x = 0.0;
@@ -273,7 +273,7 @@ void ColorSchema::writeConfig(const TQString& path) const
c.setGroup("SchemaGeneral");
c.writeEntry("Title",m_title);
c.writeEntry("ImagePath",m_imagePath);
- c.writeEntry("ImageAlignment",m_tqalignment);
+ c.writeEntry("ImageAlignment",m_alignment);
c.writeEntry("UseTransparency",m_useTransparency);
c.writeEntry("TransparentR",m_tr_r);
@@ -313,7 +313,7 @@ bool ColorSchema::rereadSchemaFile()
char line[100];
- *lastRead = TQDateTime::tqcurrentDateTime();
+ *lastRead = TQDateTime::currentDateTime();
while (fscanf(sysin,"%80[^\n]\n",line) > 0)
{
@@ -334,7 +334,7 @@ bool ColorSchema::rereadSchemaFile()
TQString qline(line);
m_imagePath = locate("wallpaper", qline.mid( qline.find(" ",7)+1 ) );
- m_tqalignment = attr;
+ m_alignment = attr;
}
if (!strncmp(line,"transparency",12))
{ float rx;
@@ -388,7 +388,7 @@ bool ColorSchema::rereadSchemaFile()
if (!(0 <= fi && fi <= TABLE_COLORS)) continue;
if (!(0 <= tr && tr <= 1 )) continue;
if (!(0 <= bo && bo <= 1 )) continue;
- m_table[fi].color = kapp->tqpalette().active().text();
+ m_table[fi].color = kapp->palette().active().text();
m_table[fi].transparent = tr;
m_table[fi].bold = bo;
}
@@ -399,7 +399,7 @@ bool ColorSchema::rereadSchemaFile()
if (!(0 <= fi && fi <= TABLE_COLORS)) continue;
if (!(0 <= tr && tr <= 1 )) continue;
if (!(0 <= bo && bo <= 1 )) continue;
- m_table[fi].color = kapp->tqpalette().active().base();
+ m_table[fi].color = kapp->palette().active().base();
m_table[fi].transparent = tr;
m_table[fi].bold = bo;
}
@@ -615,7 +615,7 @@ bool ColorSchemaList::checkSchemas()
// now.
//
//
- TQDateTime now = TQDateTime::tqcurrentDateTime();
+ TQDateTime now = TQDateTime::currentDateTime();
r = updateAllSchemaTimes(now);
diff --git a/konsole/konsole/schema.h b/konsole/konsole/schema.h
index 1027a6c9e..fa9f32412 100644
--- a/konsole/konsole/schema.h
+++ b/konsole/konsole/schema.h
@@ -150,7 +150,7 @@ protected:
int numb() {if (!m_fileRead) rereadSchemaFile();return m_numb;};
const TQString& title() {if (!m_fileRead) rereadSchemaFile();return m_title;};
const TQString& imagePath() {if (!m_fileRead) rereadSchemaFile();return m_imagePath;};
- int tqalignment() {if (!m_fileRead) rereadSchemaFile();return m_tqalignment;};
+ int alignment() {if (!m_fileRead) rereadSchemaFile();return m_alignment;};
const ColorEntry* table() {if (!m_fileRead) rereadSchemaFile();return m_table;};
bool useTransparency() {if (!m_fileRead) rereadSchemaFile();return m_useTransparency;};
double tr_x() {if (!m_fileRead) rereadSchemaFile();return m_tr_x;};
@@ -162,7 +162,7 @@ protected:
private:
int m_numb;
int m_tr_r, m_tr_g, m_tr_b;
- int m_tqalignment;
+ int m_alignment;
TQString m_title;
TQString m_imagePath;
ColorEntry m_table[TABLE_COLORS];
@@ -188,7 +188,7 @@ public:
const ColorSchema *at(unsigned int i)
{ return TQPtrList<ColorSchema>::at(i); } ;
#ifdef USE_QT4
- const ColorSchema *tqat(unsigned int i)
+ const ColorSchema *at(unsigned int i)
{ return at(i); } ;
#endif // USE_QT4
diff --git a/konsole/konsole/session.cpp b/konsole/konsole/session.cpp
index cc4293326..866d2e232 100644
--- a/konsole/konsole/session.cpp
+++ b/konsole/konsole/session.cpp
@@ -35,7 +35,7 @@
#include <tqfile.h>
#include <tqdir.h>
#include <tqregexp.h>
-#include <tqtextedit.h>
+#include <textedit.h>
/*! \class TESession
@@ -133,11 +133,11 @@ void TESession::ptyError()
{
// FIXME: sh->error() is always empty
if ( sh->error().isEmpty() )
- KMessageBox::error( te->tqtopLevelWidget(),
+ KMessageBox::error( te->topLevelWidget(),
i18n("Konsole is unable to open a PTY (pseudo teletype). It is likely that this is due to an incorrect configuration of the PTY devices. Konsole needs to have read/write access to the PTY devices."),
i18n("A Fatal Error Has Occurred") );
else
- KMessageBox::error(te->tqtopLevelWidget(), sh->error());
+ KMessageBox::error(te->topLevelWidget(), sh->error());
emit done(this);
}
@@ -645,7 +645,7 @@ void TESession::startZModem(const TQString &zmodem, const TQString &dir, const T
connect( sh,TQT_SIGNAL(block_in(const char*,int)), this, TQT_SLOT(zmodemRcvBlock(const char*,int)) );
connect( sh,TQT_SIGNAL(buffer_empty()), this, TQT_SLOT(zmodemContinue()));
- zmodemProgress = new ZModemDialog(te->tqtopLevelWidget(), false,
+ zmodemProgress = new ZModemDialog(te->topLevelWidget(), false,
i18n("ZModem Progress"));
connect(zmodemProgress, TQT_SIGNAL(user1Clicked()),
@@ -767,7 +767,7 @@ QCStringList TESession::functionsDynamic()
void TESession::onRcvBlock( const char* buf, int len )
{
em->onRcvBlock( buf, len );
- emit receivedData( TQString::tqfromLatin1( buf, len ) );
+ emit receivedData( TQString::fromLatin1( buf, len ) );
}
void TESession::print( TQPainter &paint, bool friendly, bool exact )
diff --git a/konsole/konsole/zmodem_dialog.cpp b/konsole/konsole/zmodem_dialog.cpp
index 421501c40..0fec04bc4 100644
--- a/konsole/konsole/zmodem_dialog.cpp
+++ b/konsole/konsole/zmodem_dialog.cpp
@@ -18,7 +18,7 @@
#include "zmodem_dialog.h"
-#include <tqtextedit.h>
+#include <textedit.h>
#include <klocale.h>
diff --git a/konsole/konsole/TEmulation.cpp b/konsole/konsole/TEmulation.cpp
index 7b7e1c5f4..2013e5b06 100644
--- a/konsole/konsole/TEmulation.cpp
+++ b/konsole/konsole/TEmulation.cpp
@@ -76,7 +76,7 @@
#include <stdlib.h>
#include <unistd.h>
#include <tqregexp.h>
-#include <tqclipboard.h>
+#include <clipboard.h>
#include <assert.h>
@@ -251,7 +251,7 @@ int TEmulation::keymapNo()
*/
void TEmulation::onRcvChar(int c)
// process application tqunicode input to terminal
// this is a trivial scanner
{
c &= 0xff;
@@ -284,7 +284,7 @@ void TEmulation::onKeyPress( TQKeyEvent* ev )
scr->setHistCursor(scr->getHistLines());
if (!ev->text().isEmpty())
{ // A block of text
// Note that the text is proper tqunicode.
// We should do a conversion here, but since this
// routine will never be used, we simply emit plain ascii.
emit sndBlock(TQString(ev->text()).ascii(),ev->text().length());
@@ -299,7 +299,7 @@ void TEmulation::onKeyPress( TQKeyEvent* ev )
// Unblocking, Byte to Unicode translation --------------------------------- --
/*
- We are doing code conversion from locale to tqunicode first.
+ We are doing code conversion from locale to unicode first.
*/
void TEmulation::onRcvBlock(const char *s, int len)
@@ -345,7 +345,7 @@ void TEmulation::onRcvBlock(const char *s, int len)
if (r[j].category() == TQChar::Mark_NonSpacing)
scr->compose(r.mid(j,1));
else
- onRcvChar(r[j].tqunicode());
+ onRcvChar(r[j].unicode());
}
i = l;
}
@@ -392,7 +392,7 @@ void TEmulation::clearSelection() {
void TEmulation::copySelection() {
if (!connected) return;
TQString t = scr->getSelText(true);
- TQApplication::tqclipboard()->setText(t);
+ TQApplication::clipboard()->setText(t);
}
TQString TEmulation::getSelection() {
@@ -251,7 +251,7 @@ int TEmulation::keymapNo()
*/
void TEmulation::onRcvChar(int c)
-// process application tqunicode input to terminal
+// process application unicode input to terminal
// this is a trivial scanner
{
@@ -284,7 +284,7 @@ void TEmulation::onKeyPress( TQKeyEvent* ev )
if (!ev->text().isEmpty())
{ // A block of text
- // Note that the text is proper tqunicode.
+ // Note that the text is proper unicode.
// We should do a conversion here, but since this
// routine will never be used, we simply emit plain ascii.